/* -*- coding: euc-jp-unix -*-
 *
 *  ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Moz2ch.
 *
 * The Initial Developer of the Original Code is Moz2ch Project.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/////////////////
// RDF Components
const kRDFService = Components.classes["@mozilla.org/rdf/rdf-service;1"]
        .getService(Components.interfaces.nsIRDFService);
const kRDFContainerUtils =
        Components.classes["@mozilla.org/rdf/container-utils;1"]
        .getService(Components.interfaces.nsIRDFContainerUtils);

////////////////////
// Directory Service
const kDirectoryService =
        Components.classes["@mozilla.org/file/directory_service;1"]
        .getService(Components.interfaces.nsIProperties);

/////////////
// IO Service
const kIOService = Components.classes["@mozilla.org/network/io-service;1"]
        .getService(Components.interfaces.nsIIOService);


/** 
 * <pre lang="ja">
 * (_(    
 * ( `)   ĥĥ꡼ӥ塼ӎŎ
 * (      )     : 2003/02/25
 *      񤤤  : ˼⤸顼
 * (___)__)   Ď؎ˎގ: 
 *            RDFTreeView饹äƤ줫뤫
 *            
 * </pre>
 */
var moz2chItaTreeView = new Object();

moz2chItaTreeView.id = "itaTree";
moz2chItaTreeView.elt = null;
moz2chItaTreeView.datasource = null
moz2chItaTreeView.rdfRoot = null;

const kMoz2chNS = "http://moz2ch.sourceforge.jp/index.rdf#";
const kMoz2chItaTreeViewRootURI = "http://www.2ch.net/";
const kMoz2chDirName = "Moz2ch";
const kMoz2chRDFName = "index.rdf";

const kMoz2chItaTreeTitleRes = 
        kRDFService.GetResource(kMoz2chNS + "title");
const kMoz2chItaTreeURLRes =
        kRDFService.GetResource(kMoz2chNS + "url");
const kMoz2chItaTreeTypeRes =
        kRDFService.GetResource(kMoz2chNS + "type");

moz2chItaTreeView.init =
function () {
    if (this.elt)
        return;

    this.elt = document.getElementById(this.id);

    // Moz2chǥ쥯ȥꥲȡ
    var moz2chDir = kDirectoryService
            .get("ProfD", Components.interfaces.nsIFile);
    moz2chDir.append(kMoz2chDirName);
    if (!moz2chDir.exists())
        moz2chDir.create(moz2chDir.DIRECTORY_TYPE, 0700);

    var file = moz2chDir.clone();
    file.append(kMoz2chRDFName);
    file = kIOService.newFileURI(file).spec;

    // ǡ򥻥ơ
    var ds = kRDFService.GetDataSourceBlocking(file); 
    this.datasource = ds;
    this.elt.database.AddDataSource(ds);
    this.update();

    // RDFκǤäȤ
    var res = kRDFService.GetResource(kMoz2chItaTreeViewRootURI);
    this.rdfRoot = kRDFContainerUtils.MakeSeq(this.datasource, res);
}

/** ĥĥ꡼˥ƥɲäӎŎ */
moz2chItaTreeView.addCategory =
function (title) {
    var res = kRDFService.GetResource(
            "uri:category" + this.rdfRoot.GetCount()); 
    var seq = kRDFContainerUtils.MakeSeq(this.datasource, res);
    this.datasource.Assert(res, kMoz2chItaTreeTitleRes,
            kRDFService.GetLiteral(title), true);

    this.rdfRoot.AppendElement(res);
    this.update();
};

moz2chItaTreeView.addIta =
function (title, url, type) {
    if (this.elt.currentIndex < 0)
        return;

    var seq = kRDFContainerUtils.MakeSeq(this.datasource,
            this.elt.builderView.getResourceAtIndex(this.elt.currentIndex));
    var res = kRDFService.GetResource("uri:item" + seq.GetCount());
    this.datasource.Assert(res, kMoz2chItaTreeTitleRes,
            kRDFService.GetLiteral(title), true);
    this.datasource.Assert(res, kMoz2chItaTreeURLRes, 
            kRDFService.GetLiteral(url), true);
    this.datasource.Assert(res, kMoz2chItaTreeTypeRes,
            kRDFService.GetLiteral(type), true);

    seq.AppendElement(res);
    this.update();
}

/** RDFξ֤ȿǤ */
moz2chItaTreeView.update =
function () {
    this.elt.builder.rebuild();
};


/////////////////////////////////////////////
// ͎ގݎĎʎݎĎގ׎(ߢώ)!!!!

function onAdd(e) {
    var title = document.getElementById("titleBox").value;
    var url = document.getElementById("urlBox").value;
    var type = document.getElementById("typeBox").value;
    moz2chItaTreeView.addIta(title, url, type);
}

function onAddCategory(e) {
    var title = document.getElementById("titleBox").value;
    moz2chItaTreeView.addCategory(title);
}

function onItaTreeViewLoad(e) {
    moz2chItaTreeView.init();
}
addEventListener("load", onItaTreeViewLoad, false);

